@@ -17,6 +17,8 @@ async def retry_connect(
     last_error: asyncssh.Error | asyncio.TimeoutError | None = None
     algorithm_options = {
         "encryption_algs": [
+            "aes128-gcm@openssh.com",
+            "aes256-gcm@openssh.com",
             "chacha20-poly1305@openssh.com",
             "aes128-ctr",
             "aes256-ctr",
@@ -68,7 +70,7 @@ def get_ssh_keys(key_path: str | None, default_key: str | None) -> list[str]:
     if default_key:
         return [default_key]
     # If key path is # (not specified) and default key is also not specified via -K
-    common_ssh_dir = os.path.expanduser("~/.ssh")
+    common_ssh_dir = os.path.expanduser(os.path.join("~", ".ssh"))
     common_keys = [
         os.path.join(common_ssh_dir, key)
         for key in ["id_ed25519", "id_rsa", "id_ecdsa", "id_dsa"]
@@ -188,9 +190,10 @@ async def execute(
             output = await execute_command(
                 conn, ssh_command, remote_width, color
             )
-            # Put output into the host's output queue
+            # Put the output into the host's output queue
             await output_queue.put(output)
         else:
+            # Stream the output to the host's output queue
             await stream_command_output(
                 conn, ssh_command, remote_width, output_queue, color
             )
